/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __C_WRAPPER_H__
#define __C_WRAPPER_H__

#include <glib.h>
#include "singit_song.h"

#ifdef __cplusplus
extern "C" {
#endif // __cplusplus

void opengl_lyrics_init();
void opengl_lyrics_draw(guint time, gboolean rotate, gboolean beat, gfloat level[3]);
void opengl_lyrics_free();
void opengl_lyrics_set_song(SingitSong *song);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // __C_WRAPPER_H__
